@@ -19,9 +19,7 @@ def syncdb():
     manage('syncdb --noinput')
 
 def compress():
-    from django.conf import settings
-    if 'compress' in settings.INSTALLED_APPS:
-        manage('synccompress')
+    manage('synccompress')
 
 def test():
     pass
